==> jet-bridge-base-1.8.10.tar.gz: jet-bridge-base-1.8.10/jet_bridge_base/utils/track_model.py <==
import json

import requests

from jet_bridge_base import settings
from jet_bridge_base.encoders import JSONEncoder
from jet_bridge_base.sentry import sentry_controller
from jet_bridge_base.utils.async_exec import as_future


def track_model(request, model, action, uid, model_data):
    if not settings.TRACK_MODELS_ENDPOINT:
        return

    if request.project is None or request.environment is None or request.resource_token is None:
        error = 'MODEL_CHANGE incorrect request: {} {} {}'.format(request.project, request.environment, request.resource_token)
        sentry_controller.capture_message(error)
        return

    url = '{}/model_change'.format(settings.TRACK_MODELS_ENDPOINT)
    headers = {
        'Content-Type': 'application/json'
    }
    data = {
        'project': request.project,
        'environment': request.environment,
        'resource_token': request.resource_token,
        'model': model,
        'action': action,
        'data': model_data
    }

    if uid is not None:
        data['id'] = uid

    if settings.TRACK_MODELS_AUTH:
        headers['Authorization'] = settings.TRACK_MODELS_AUTH

    data_str = json.dumps(data, cls=JSONEncoder)

    try:
        r = requests.post(url, data=data_str, headers=headers)
        success = 200 <= r.status_code < 300

        if not success:
            error = 'MODEL_CHANGE request error: {} {} {}'.format(r.status_code, r.reason, r.text)
            sentry_controller.capture_message(error)
    except Exception as e:
        sentry_controller.capture_exception(e)


def track_model_async(request, model, action, uid, data):
    if not settings.TRACK_MODELS_ENDPOINT:
        return

    try:
        import asyncio
    except:
        return

    loop = asyncio.new_event_loop()
    asyncio.set_event_loop(loop)
    as_future(lambda: track_model(request, model, action, uid, data))

==> jet-bridge-base-1.9.10.tar.gz: jet-bridge-base-1.9.10/jet_bridge_base/utils/track_model.py <==
import json

import requests

from jet_bridge_base import settings
from jet_bridge_base.configuration import configuration
from jet_bridge_base.encoders import JSONEncoder
from jet_bridge_base.sentry import sentry_controller


def track_model(project, environment, resource_token, model, action, uid, model_data):
    if not settings.TRACK_MODELS_ENDPOINT:
        return

    if project is None or environment is None or resource_token is None:
        error = 'MODEL_CHANGE incorrect request: {} {} {}'.format(project, environment, resource_token)
        sentry_controller.capture_message(error)
        return

    url = '{}/model_change'.format(settings.TRACK_MODELS_ENDPOINT)
    headers = {
        'Content-Type': 'application/json'
    }
    data = {
        'project': project,
        'environment': environment,
        'resource_token': resource_token,
        'model': model,
        'action': action,
        'data': model_data
    }

    if uid is not None:
        data['id'] = uid

    if settings.TRACK_MODELS_AUTH:
        headers['Authorization'] = settings.TRACK_MODELS_AUTH

    data_str = json.dumps(data, cls=JSONEncoder)

    try:
        r = requests.post(url, data=data_str, headers=headers)
        success = 200 <= r.status_code < 300

        if not success:
            error = 'MODEL_CHANGE request error: {} {} {}'.format(r.status_code, r.reason, r.text)
            sentry_controller.capture_message(error)
    except Exception as e:
        sentry_controller.capture_exception(e)


def track_model_async(request, model, action, uid, data):
    if not settings.TRACK_MODELS_ENDPOINT:
        return

    configuration.run_async(track_model, request.project, request.environment, request.resource_token, model, action, uid, data)
